Changix v1.0.0 Changix View Source
Compile-time changelog features from static changelog files. Including the module will provide with following functions:
changelog_entries/0, which return all changelog entries ordered by desc datechangelog_entry/1, which takes a date and returns a single entry
include Changix can take following options:
path: changelog folder. Defaults to "changelog"renderer: function that takes 2 parameters(markdown, changelog_path) and should return{:ok, html}or{:error, reason}. Defaults to Earmark implementation.read_more_class: css class used to render the read more link. Defaults toread_more.read_more_label: label used to used to render the read more link. Defaults to "Read more".